MastodonResponse<D> class

The class represents the response from Mastodon API.

Constructors

MastodonResponse({required Map<String, String> headers, required HttpStatus status, required MastodonRequest request, required RateLimit rateLimit, required D data})
Returns the new instance of MastodonResponse.
const

Properties

data → D
The data field
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
The headers of this response.
final
rateLimit → RateLimit
The rate limit
final
request → MastodonRequest
The request that generated this response.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → HttpStatus
The HTTP status from Mastodon API server.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited